@@ -9,14 +9,14 @@ function blue_geo_watch_targets() {
         return
     fi
 
-    local function_name=blue_geo_watch_targets_$task
-    if [[ $(type -t $function_name) == "function" ]]; then
-        $function_name "${@:2}"
+    if [ "$2" == "help" ]; then
+        abcli_show_usage_2 blue_geo watch targets $task
         return
     fi
 
-    if [ "$2" == "help" ]; then
-        abcli_show_usage_2 blue_geo watch targets $task
+    local function_name=blue_geo_watch_targets_$task
+    if [[ $(type -t $function_name) == "function" ]]; then
+        $function_name "${@:2}"
         return
     fi
 
@@ -26,25 +26,25 @@ function blue_geo_watch_targets() {
         return
     fi
 
-    if [[ ",get,list,save," == *","$task","* ]]; then
+    if [[ ",get,list," == *","$task","* ]]; then
         python3 -m blue_geo.watch.targets "$@"
         return
     fi
 
-    if [[ ",download,upload," == *","$task","* ]]; then
-        abcli_$task - $BLUE_GEO_WATCH_TARGET_LIST
-        return
-    fi
-
     if [[ "$task" == "publish" ]]; then
         abcli_publish \
-            as=geo-watch-targets,suffix=.yaml \
+            as=geo-watch-targets,tar \
             $BLUE_GEO_WATCH_TARGET_LIST
         return
     fi
 
-    abcli_log_error "@geo: watch: $task: command not found."
+    if [[ "$task" == "test" ]]; then
+        python3 -m blue_geo.watch.targets test
+        return
+    fi
+
+    abcli_log_error "@targets: $task: command not found."
     return 1
 }
 
-abcli_source_path - caller,suffix=/targets
+abcli_source_caller_suffix_path /targets
